searchData={"items":[{"type":"module","title":"Inherit","doc":"Inherit provides a way to create pseudo-inheritance in Elixir by allowing modules\nto inherit struct fields and delegate function calls from other modules.","ref":"Inherit.html"},{"type":"module","title":"Usage - Inherit","doc":"To make a module inheritable, use `Inherit`:\n\n    defmodule Parent do\n      use Inherit, [\n        field1: \"default_value\",\n        field2: 42\n      ]\n\n      def some_function(value) do\n        # function implementation\n      end\n    end\n\nTo inherit from a module:\n\n    defmodule Child do\n      use Parent, [\n        field3: \"additional_field\"\n      ]\n\n      # Child now has field1, field2, and field3\n      # Child can call Parent.some_function/1 directly\n    end","ref":"Inherit.html#module-usage"},{"type":"module","title":"Examples - Inherit","doc":"iex> defmodule Person do\n    ...>   use Inherit, [name: \"\", age: 0]\n    ...>   def greet(person) do\n    ...>     \"Hello, I'm #{person.name} and I'm #{person.age} years old\"\n    ...>   end\n    ...> end\n    iex> defmodule Employee do\n    ...>   use Person, [salary: 0]\n    ...> end\n    iex> emp = %Employee{name: \"John\", age: 30, salary: 50000}\n    iex> Employee.greet(emp)\n    \"Hello, I'm John and I'm 30 years old\"","ref":"Inherit.html#module-examples"},{"type":"macro","title":"Inherit.__using__/1","doc":"Makes a module inheritable by defining its struct and enabling inheritance.\n\nThis macro sets up a module to be used as a parent for inheritance by other modules.","ref":"Inherit.html#__using__/1"},{"type":"macro","title":"Parameters - Inherit.__using__/1","doc":"- `fields` - A keyword list defining the struct fields and their default values","ref":"Inherit.html#__using__/1-parameters"},{"type":"macro","title":"Inherit.from/2","doc":"Creates an inheritable module that can be used by other modules.\n\nThis macro sets up a module to be inherited by defining a `__using__/1` macro\nthat delegates function calls and merges struct fields.","ref":"Inherit.html#from/2"},{"type":"macro","title":"Parameters - Inherit.from/2","doc":"- `module` - The module to inherit from\n- `fields` - A keyword list of additional fields to add to the struct","ref":"Inherit.html#from/2-parameters"},{"type":"extras","title":"Inherit","doc":"# Inherit\n\nInherit provides a way to create pseudo-inheritance in Elixir by allowing modules to inherit struct fields and delegate function calls from other modules.","ref":"readme.html"},{"type":"extras","title":"Features - Inherit","doc":"- **Struct inheritance**: Child modules inherit all fields from parent modules\n- **Function delegation**: Public functions from parent modules are automatically delegated\n- **Field merging**: Child modules can add additional fields to inherited structs\n- **Overridable functions**: Inherited functions can be overridden in child modules","ref":"readme.html#features"},{"type":"extras","title":"Usage - Inherit","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Making a module inheritable - Inherit","doc":"Use `Inherit` in your module and define struct fields:\n\n```elixir\ndefmodule Person do\n  use Inherit, [\n    name: \"\",\n    age: 0\n  ]\n\n  def greet(person) do\n    \"Hello, I'm #{person.name} and I'm #{person.age} years old\"\n  end\n\n  def adult?(person) do\n    person.age >= 18\n  end\nend\n```","ref":"readme.html#making-a-module-inheritable"},{"type":"extras","title":"Inheriting from a module - Inherit","doc":"Use the parent module in your child module and specify additional fields:\n\n```elixir\ndefmodule Employee do\n  use Person, [\n    salary: 0,\n    department: \"\"\n  ]\n\n  # Override parent function\n  def greet(employee) do\n    \"Hi, I'm #{employee.name}, I work in #{employee.department}\"\n  end\nend\n```","ref":"readme.html#inheriting-from-a-module"},{"type":"extras","title":"Using the inherited module - Inherit","doc":"```elixir\n# Create an Employee struct with inherited fields\nemployee = %Employee{\n  name: \"John\",\n  age: 30,\n  salary: 50000,\n  department: \"Engineering\"\n}\n\n# Call overridden function\nEmployee.greet(employee)\n# => \"Hi, I'm John, I work in Engineering\"\n\n# Call inherited function\nEmployee.adult?(employee)\n# => true\n```","ref":"readme.html#using-the-inherited-module"},{"type":"extras","title":"How it works - Inherit","doc":"1. **Parent module setup**: When you `use Inherit`, the module becomes inheritable and defines its own struct\n2. **Inheritance**: When you `use ParentModule`, the child module:\n   - Inherits all struct fields from the parent\n   - Adds any additional fields specified\n   - Delegates all public functions from the parent module\n   - Makes inherited functions overridable","ref":"readme.html#how-it-works"},{"type":"extras","title":"Installation - Inherit","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `inherit` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:inherit, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - Inherit","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2025 DockYard, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}